@@ -2,51 +2,58 @@
 #
 # SPDX-License-Identifier: MIT
 import re
-from functools import lru_cache
-from functools import partial
-from typing import Optional, Union, List
+from functools import lru_cache, partial
+from typing import List, Optional, Union
 
+from edgar._filings import Attachment, Attachments, Filing, FilingHeader, FilingHomepage, Filings, get_by_accession_number, get_by_accession_number_enriched, get_filings
+from edgar.core import CAUTION, CRAWL, NORMAL, edgar_mode, get_identity, listify, set_identity
+from edgar.current_filings import CurrentFilings, get_all_current_filings, get_current_filings, iter_current_filings_pages
 from edgar.entity import (
-    Entity,
-    EntityData,
     Company,
     CompanyData,
-    CompanySearchResults,
-    CompanyFilings,
     CompanyFiling,
+    CompanyFilings,
+    CompanySearchResults,
+    Entity,
+    EntityData,
     find_company,
-    get_entity,
+    get_cik_lookup_data,
     get_company_facts,
     get_company_tickers,
-    get_icon_from_ticker,
+    get_entity,
     get_entity_submissions,
+    get_icon_from_ticker,
     get_ticker_to_cik_lookup,
-    get_cik_lookup_data
 )
-from edgar._filings import (Filing,
-                            Filings,
-                            FilingHeader,
-                            Attachment,
-                            Attachments,
-                            get_filings,
-                            get_by_accession_number,
-                            FilingHomepage)
-from edgar.current_filings import CurrentFilings, get_current_filings, iter_current_filings_pages, get_all_current_filings
-from edgar.core import (edgar_mode,
-                        CRAWL,
-                        CAUTION,
-                        NORMAL,
-                        get_identity,
-                        set_identity,
-                        listify)
-from edgar.funds.reports import FundReport, NPORT_FORMS
-from edgar.funds import FundCompany, FundSeries,  FundClass, find_fund
-from edgar.thirteenf import ThirteenF, THIRTEENF_FORMS
-from edgar.xbrl import XBRL
-from edgar.files.html import Document
 from edgar.files import detect_page_breaks, mark_page_breaks
+from edgar.files.html import Document
 from edgar.financials import Financials, MultiFinancials
-from edgar.storage import use_local_storage, is_using_local_storage, set_local_storage_path, download_edgar_data, download_filings
+from edgar.funds import FundClass, FundCompany, FundSeries, find_fund
+from edgar.funds.reports import NPORT_FORMS, FundReport
+from edgar.storage import download_edgar_data, download_filings, is_using_local_storage, set_local_storage_path, use_local_storage
+from edgar.storage_management import (
+    StorageAnalysis,
+    StorageInfo,
+    analyze_storage,
+    availability_summary,
+    check_filing,
+    check_filings_batch,
+    cleanup_storage,
+    clear_cache,
+    optimize_storage,
+    storage_info,
+)
+from edgar.thirteenf import THIRTEENF_FORMS, ThirteenF
+from edgar.xbrl import XBRL
+
+# Fix for Issue #457: Clear locale-corrupted cache files on first import
+# This is a one-time operation that only runs if the marker file doesn't exist
+try:
+    from edgar.httpclient import clear_locale_corrupted_cache
+    clear_locale_corrupted_cache()
+except Exception:
+    # Silently continue if cache clearing fails - it's not critical
+    pass
 
 # Another name for get_current_filings
 get_latest_filings = get_current_filings
@@ -81,10 +88,10 @@ def find(search_id: Union[str, int]) -> Optional[Union[Filing, Entity, CompanySe
     if isinstance(search_id, int):
         return Entity(search_id)
     elif re.match(r"\d{10}-\d{2}-\d{6}", search_id):
-        return get_by_accession_number(search_id)
+        return get_by_accession_number_enriched(search_id)
     elif re.match(r"^\d{18}$", search_id): # accession number with no dashes
         accession_number = search_id[:10] + "-" + search_id[10:12] + "-" + search_id[12:]
-        return get_by_accession_number(accession_number)
+        return get_by_accession_number_enriched(accession_number)
     elif re.match(r"\d{4,10}$", search_id):
         return Entity(search_id)
     elif re.match(r"^[A-WYZ]{1,5}([.-][A-Z])?$", search_id):  # Ticker (including dot or hyphenated)
@@ -124,12 +131,12 @@ def obj(sec_filing: Filing) -> Optional[object]:
     :param sec_filing: The filing
     :return:
     """
-    from edgar.company_reports import TenK, TenQ, TwentyF, EightK, CurrentReport
+    from edgar.company_reports import CurrentReport, EightK, TenK, TenQ, TwentyF
     from edgar.effect import Effect
-    from edgar.offerings import FormC, FormD
-    from edgar.ownership import Ownership, Form3, Form4, Form5
     from edgar.form144 import Form144
     from edgar.muniadvisors import MunicipalAdvisorForm
+    from edgar.offerings import FormC, FormD
+    from edgar.ownership import Form3, Form4, Form5, Ownership
 
     if matches_form(sec_filing, "6-K"):
         return CurrentReport(sec_filing)
