@@ -6,11 +6,11 @@ import webbrowser
 from contextlib import nullcontext
 from dataclasses import dataclass
 from datetime import datetime
-from functools import lru_cache, cached_property
+from functools import cached_property, lru_cache
 from io import BytesIO
 from os import PathLike
 from pathlib import Path
-from typing import Tuple, List, Dict, Union, Optional, Any, cast
+from typing import Any, Dict, List, Optional, Tuple, Union, cast
 
 import httpx
 import numpy as np
@@ -29,47 +29,41 @@ from rich.text import Text
 
 from edgar._markdown import text_to_markdown
 from edgar._party import Address
-from edgar.attachments import FilingHomepage, Attachment, Attachments, AttachmentServer
-from edgar.core import (log, sec_edgar,
-                        listify,
-                        cache_except_none,
-                        is_start_of_quarter,
-                        is_probably_html,
-                        IntString,
-                        current_year_and_quarter,
-                        Years,
-                        Quarters,
-                        YearAndQuarter,
-                        YearAndQuarters,
-                        quarters_in_year,
-                        filing_date_to_year_quarters,
-                        DataPager,
-                        PagingState,
-                        parallel_thread_map)
+from edgar.attachments import Attachment, Attachments, AttachmentServer, FilingHomepage
+from edgar.core import (
+    DataPager,
+    IntString,
+    PagingState,
+    Quarters,
+    YearAndQuarter,
+    YearAndQuarters,
+    Years,
+    cache_except_none,
+    current_year_and_quarter,
+    filing_date_to_year_quarters,
+    is_probably_html,
+    is_start_of_quarter,
+    listify,
+    log,
+    parallel_thread_map,
+    quarters_in_year,
+    sec_edgar,
+)
 from edgar.dates import InvalidDateException
 from edgar.files.html import Document
 from edgar.files.html_documents import get_clean_html
 from edgar.files.htmltools import html_sections
 from edgar.files.markdown import to_markdown
-from edgar.filtering import (
-    filter_by_date,
-    filter_by_form,
-    filter_by_cik,
-    filter_by_exchange,
-    filter_by_ticker,
-    filter_by_accession_number
-)
-from edgar.formatting import accession_number_text
-from edgar.formatting import display_size
+from edgar.filtering import filter_by_accession_number, filter_by_cik, filter_by_date, filter_by_exchange, filter_by_form, filter_by_ticker
+from edgar.formatting import accession_number_text, display_size
 from edgar.headers import FilingDirectory, IndexHeaders
 from edgar.httprequests import download_file, download_text, download_text_between_tags
 from edgar.reference import describe_form
-from edgar.reference.tickers import Exchange
-from edgar.reference.tickers import find_ticker, find_ticker_safe
-from edgar.richtools import repr_rich, print_rich, rich_to_text, Docs
+from edgar.reference.tickers import Exchange, find_ticker, find_ticker_safe
+from edgar.richtools import Docs, print_rich, repr_rich, rich_to_text
 from edgar.search import BM25Search, RegexSearch
-from edgar.sgml import FilingSGML, Reports, Statements, FilingHeader
-from edgar.storage import local_filing_path, is_using_local_storage
+from edgar.sgml import FilingHeader, FilingSGML, Reports, Statements
+from edgar.storage import is_using_local_storage, local_filing_path
 from edgar.xbrl import XBRL, XBRLFilingWithNoXbrlData
 
 """ Contain functionality for working with SEC filing indexes and filings
@@ -193,7 +187,7 @@ class FileSpecs:
 
     def __init__(self, specs: List[Tuple[str, Tuple[int, int], pa.lib.DataType]]):
         self._spec_type = specs[0][0].title()
-        self.splits = list(zip(*specs))[1]
+        self.splits = list(zip(*specs, strict=False))[1]
         self.schema = pa.schema(
             [
                 pa.field(name, datatype)
@@ -467,14 +461,14 @@ class Filings:
     def save(self, location: str):
         """Save the filing index as parquet"""
         self.save_parquet(location)
-        
+
     def download(self, data_directory: Optional[str] = None):
         """
         Download the filings based on the accession numbers in this Filings object.
-        
+
         This is a convenience method that calls `download_filings` with this object
         as the `filings` parameter.
-        
+
         Args:
             data_directory: Directory to save the downloaded files. Defaults to the Edgar data directory.
         """
@@ -483,14 +477,39 @@ class Filings:
                          overwrite_existing=True,
                          filings=self)
 
-    def get_filing_at(self, item: int):
-        """Get the filing at the specified index"""
+    def get_filing_at(self, item: int, enrich: bool = True):
+        """Get filing at index, optionally enriching with related entities"""
+        # Get the primary filing data
+        accession_no = self.data['accession_number'][item].as_py()
+
+        related_entities = []
+        if enrich:
+            # Use PyArrow to find all entities with same accession number
+            # Limit search to nearby entries for performance (+/- 10 positions)
+            start = max(0, item - 10)
+            end = min(len(self.data), item + 11)
+
+            # Slice the data and search efficiently
+            slice_data = self.data.slice(start, end - start)
+            mask = pc.equal(slice_data['accession_number'], accession_no)
+
+            for idx in range(len(mask)):
+                if mask[idx].as_py():
+                    actual_idx = start + idx
+                    if actual_idx != item:  # Skip the primary filing
+                        related_entities.append({
+                            'cik': slice_data['cik'][idx].as_py(),
+                            'company': slice_data['company'][idx].as_py()
+                        })
+
+        # Create Filing with related entities
         return Filing(
             cik=self.data['cik'][item].as_py(),
             company=self.data['company'][item].as_py(),
             form=self.data['form'][item].as_py(),
             filing_date=self.data['filing_date'][item].as_py(),
-            accession_no=self.data['accession_number'][item].as_py(),
+            accession_no=accession_no,
+            related_entities=related_entities
         )
 
     @property
@@ -795,6 +814,7 @@ class Filings:
         table.add_column("Company", style="bold green", width=38, no_wrap=True)
         table.add_column("Filing Date", width=11)
         table.add_column("Accession Number", width=20)
+        table.add_column(" ", width=1, style="cyan dim")  # Group indicator column
 
         # Get current page from data pager
         current_page = self.data_pager.current()
@@ -802,6 +822,26 @@ class Filings:
         # Calculate start index for proper indexing
         start_idx = self._original_state.page_start if self._original_state else self.data_pager.start_index
 
+        # Identify groups of consecutive filings with same accession number
+        groups = {}
+        accession_numbers = [current_page['accession_number'][i].as_py() for i in range(len(current_page))]
+
+        for i in range(len(accession_numbers)):
+            acc_no = accession_numbers[i]
+
+            # Check previous and next accession numbers
+            prev_acc = accession_numbers[i-1] if i > 0 else None
+            next_acc = accession_numbers[i+1] if i < len(accession_numbers)-1 else None
+
+            if acc_no != prev_acc and acc_no == next_acc:
+                groups[i] = '┐'  # Start of group
+            elif acc_no == prev_acc and acc_no == next_acc:
+                groups[i] = '│'  # Middle of group
+            elif acc_no == prev_acc and acc_no != next_acc:
+                groups[i] = '┘'  # End of group
+            else:
+                groups[i] = ' '   # Standalone filing
+
         # Iterate through rows in current page
         for i in range(len(current_page)):
             cik = current_page['cik'][i].as_py()
@@ -814,7 +854,8 @@ class Filings:
                 ticker,
                 current_page['company'][i].as_py(),
                 str(current_page['filing_date'][i].as_py()),
-                accession_number_text(current_page['accession_number'][i].as_py())
+                accession_number_text(current_page['accession_number'][i].as_py()),
+                groups.get(i, ' ')  # Add group indicator
             ]
             table.add_row(*row)
 
@@ -972,10 +1013,10 @@ def get_filings(year: Optional[Years] = None,
     if len(year_and_quarters) == 0:
         log.warning(f"""
     Provide a year between 1994 and {datetime.now().year} and optionally a quarter (1-4) for which the SEC has filings. 
-    
+
         e.g. filings = get_filings(2023) OR
              filings = get_filings(2023, 1)
-    
+
     (You specified the year {year} and quarter {quarter})   
         """)
         return None
@@ -1074,7 +1115,8 @@ class Filing:
                  company: str,
                  form: str,
                  filing_date: str,
-                 accession_no: str):
+                 accession_no: str,
+                 related_entities: List[Dict] = None):
         self.cik = cik
         self.company = company
         self.form = form
@@ -1083,6 +1125,9 @@ class Filing:
         self._filing_homepage = None
         self._sgml = None
 
+        # New: Store related entities from index
+        self._related_entities = related_entities or []
+
     @property
     def docs(self):
         return Docs(self)
@@ -1091,6 +1136,95 @@ class Filing:
     def accession_number(self):
         return self.accession_no
 
+    @property
+    def all_ciks(self) -> List[int]:
+        """Get all CIKs including related entities"""
+        # If we have related entities from the index, use those
+        if self._related_entities:
+            ciks = [self.cik]
+            ciks.extend(e['cik'] for e in self._related_entities)
+            return sorted(list(set(ciks)))
+
+        # Otherwise, check the header for all filers
+        try:
+            header = self.header
+            if header and header.filers and len(header.filers) > 1:
+                # Multiple filers in header
+                ciks = []
+                for filer in header.filers:
+                    if filer.company_information and filer.company_information.cik:
+                        # Convert CIK string to int, removing leading zeros
+                        cik_int = int(filer.company_information.cik.lstrip('0'))
+                        ciks.append(cik_int)
+                if ciks:
+                    return sorted(list(set(ciks)))
+        except Exception as e:
+            # Log warning when header access fails
+            log.warning(
+                f"Could not access header for multi-entity detection in Filing "
+                f"(accession_no={self.accession_no}, cik={self.cik}): {str(e)}. "
+                f"This may occur if the accession number is invalid or the filing doesn't exist on EDGAR."
+            )
+
+        return [self.cik]
+
+    @property
+    def all_entities(self) -> List[Dict[str, Any]]:
+        """Get all entity information"""
+        # If we have related entities from the index, use those
+        if self._related_entities:
+            entities = [{'cik': self.cik, 'company': self.company}]
+            entities.extend(self._related_entities)
+            return entities
+
+        # Otherwise, check the header for all filers
+        try:
+            header = self.header
+            if header and header.filers and len(header.filers) > 1:
+                # Multiple filers in header
+                entities = []
+                for filer in header.filers:
+                    if filer.company_information and filer.company_information.cik:
+                        # Convert CIK string to int, removing leading zeros
+                        cik_int = int(filer.company_information.cik.lstrip('0'))
+                        entities.append({
+                            'cik': cik_int,
+                            'company': filer.company_information.name or f'CIK {cik_int}'
+                        })
+                if entities:
+                    return entities
+        except Exception as e:
+            # Log warning when header access fails
+            log.warning(
+                f"Could not access header for entity information in Filing "
+                f"(accession_no={self.accession_no}, cik={self.cik}): {str(e)}. "
+                f"This may occur if the accession number is invalid or the filing doesn't exist on EDGAR."
+            )
+
+        return [{'cik': self.cik, 'company': self.company}]
+
+    @property
+    def is_multi_entity(self) -> bool:
+        """Check if this filing has multiple entities"""
+        # First check if we have related entities from the index
+        if len(self._related_entities) > 0:
+            return True
+
+        # Otherwise, check the header for multiple filers
+        try:
+            header = self.header
+            if header and header.filers and len(header.filers) > 1:
+                return True
+        except Exception as e:
+            # Log warning when header access fails
+            log.warning(
+                f"Could not access header for multi-entity check in Filing "
+                f"(accession_no={self.accession_no}, cik={self.cik}): {str(e)}. "
+                f"This may occur if the accession number is invalid or the filing doesn't exist on EDGAR."
+            )
+
+        return False
+
     @property
     def document(self):
         """
@@ -1210,7 +1344,7 @@ class Filing:
     def markdown(self, include_page_breaks: bool = False, start_page_number: int = 0) -> str:
         """
         Return the markdown version of this filing html
-        
+
         Args:
             include_page_breaks: If True, include page break delimiters in the markdown
             start_page_number: Starting page number for page break markers (default: 0)
@@ -1226,11 +1360,14 @@ class Filing:
     def view(self):
         """Preview this filing's primary document as markdown. This should display in the console"""
         html_content = self.html()
-        if html_content:
+        if html_content and is_probably_html(html_content):
             document = Document.parse(html_content)
             print_rich(document)
         else:
-            print(self.text())
+            # Fallback to text content for forms without HTML (like UPLOAD forms)
+            text_content = self.text()
+            if text_content:
+                print(text_content)
 
     def xbrl(self) -> Optional[XBRL]:
         """
@@ -1389,9 +1526,9 @@ class Filing:
             data = json.load(file)
             return cls.from_dict(data)
 
-    @property
-    @lru_cache(maxsize=1)
+    @cached_property
     def header(self):
+        """Get the header for the filing"""
         _sgml = self.sgml()
         return _sgml.header
 
@@ -1421,11 +1558,11 @@ class Filing:
         assert html is not None
         return html_sections(html)
 
-    @lru_cache(maxsize=1)
+    @cached_property
     def __get_bm25_search_index(self):
         return BM25Search(self.sections())
 
-    @lru_cache(maxsize=1)
+    @cached_property
     def __get_regex_search_index(self):
         return RegexSearch(self.sections())
 
@@ -1434,8 +1571,8 @@ class Filing:
                regex=False):
         """Search for the query string in the filing HTML"""
         if regex:
-            return self.__get_regex_search_index().search(query)
-        return self.__get_bm25_search_index().search(query)
+            return self.__get_regex_search_index.search(query)
+        return self.__get_bm25_search_index.search(query)
 
     @property
     def filing_url(self) -> str:
@@ -1565,13 +1702,31 @@ class Filing:
         ticker = find_ticker_safe(self.cik)
         ticker = f"{ticker}" if ticker else ""
 
+        # Check for multi-entity (without triggering header lookup)
+        has_related = hasattr(self, '_related_entities') and self._related_entities
+
+        # Build the title components
+        title_parts = [
+            (f"Form {self.form} ", "bold"),
+            (self.company, "bold green"),
+            " ",
+            (f"[{self.cik}] ", "dim"),
+        ]
+
+        if ticker:
+            title_parts.append((ticker, "bold yellow"))
+
+        # Add multi-entity indicator if present
+        if has_related:
+            num_related = len(self._related_entities)
+            title_parts.extend([
+                " ",
+                (f"(+{num_related} {'entity' if num_related == 1 else 'entities'})", "cyan dim")
+            ])
+
         # The title of the panel
-        title = Text.assemble((f"Form {self.form} ", "bold"),
-                              (self.company, "bold green"),
-                              " ",
-                              (f"[{self.cik}] ", "dim"),
-                              (ticker, "bold yellow")
-                              )
+        title = Text.assemble(*title_parts)
+
         # The subtitle of the panel
         subtitle = Text(describe_form(self.form, False), "dim")
 
@@ -1584,12 +1739,45 @@ class Filing:
                                   Text(str(self.filing_date), "bold"),
                                   Text(self.period_of_report or "-", "bold"),
                                   f"{len(attachments)}")
+
+        # Build content elements
+        elements = [filing_info_table]
+
+        # Add entities table if multi-entity filing
+        if has_related:
+            # Add spacing and header
+            elements.append(Text())  # Empty line for spacing
+            elements.append(Text("All Entities:", style="bold dim"))
+
+            # Create entities table
+            entities_table = Table(
+                "CIK", "Company",
+                header_style="dim",
+                box=box.SIMPLE,
+                show_edge=False,
+                padding=(0, 1)
+            )
+
+            # Add primary entity
+            entities_table.add_row(
+                Text(str(self.cik), style="dim"),
+                Text(self.company, style="bold green")
+            )
+
+            # Add related entities
+            for entity in self._related_entities:
+                entities_table.add_row(
+                    Text(str(entity.get('cik', '')), style="dim"),
+                    Text(entity.get('company', ''), style="green")
+                )
+
+            elements.append(entities_table)
+
         return Panel(
-            Group(filing_info_table),
+            Group(*elements),
             title=title,
             subtitle=subtitle,
             box=box.ROUNDED,
-            height=8,
             expand=False
         )
 
@@ -1653,6 +1841,54 @@ def get_filing_by_accession(accession_number: str, year: int):
     return None
 
 
+def get_by_accession_number_enriched(accession_number: str):
+    """Get filing with all related entities populated using PyArrow"""
+    year = int("19" + accession_number[11:13]) if accession_number[11] == '9' else int("20" + accession_number[11:13])
+
+    # Find all entities with this accession number
+    all_entities = []
+    for quarter in range(1, 5):
+        filings = _get_cached_filings(year=year, quarter=quarter)
+        if filings:
+            # Use PyArrow filtering (same pattern as Filings.get())
+            mask = pc.equal(filings.data['accession_number'], accession_number)
+            # Convert mask to indices
+            indices = []
+            for i in range(len(mask)):
+                if mask[i].as_py():
+                    indices.append(i)
+
+            if len(indices) > 0:
+                # Extract all matching entities efficiently
+                for idx in indices:
+                    all_entities.append({
+                        'cik': filings.data['cik'][idx].as_py(),
+                        'company': filings.data['company'][idx].as_py(),
+                        'form': filings.data['form'][idx].as_py(),
+                        'filing_date': filings.data['filing_date'][idx].as_py()
+                    })
+                break  # Found matches, no need to check other quarters
+
+    if all_entities:
+        # Return first entity as primary, with others as related
+        primary = all_entities[0]
+        related = all_entities[1:] if len(all_entities) > 1 else []
+
+        # Create enriched Filing
+        filing = Filing(
+            cik=primary['cik'],
+            company=primary['company'],
+            form=primary['form'],
+            filing_date=primary['filing_date'],
+            accession_no=accession_number,
+            related_entities=related
+        )
+        return filing
+
+    # Fall back to current behavior if not found
+    return get_by_accession_number(accession_number)
+
+
 def get_by_accession_number(accession_number: str, show_progress: bool = False):
     """Wrapper that handles progress display and current time logic"""
     year = int("19" + accession_number[11:13]) if accession_number[11] == '9' else int("20" + accession_number[11:13])
