@@ -2,23 +2,17 @@
 """Minimal working MCP server for EdgarTools"""
 
 # Test imports first
-print("Testing imports...")
 
 try:
     from mcp.server import Server
-    print("✓ Server import OK")
-except ImportError as e:
-    print(f"✗ Server import failed: {e}")
+except ImportError:
     exit(1)
 
-try: 
-    from mcp.types import Tool, Resource, TextContent
-    print("✓ Types import OK")
-except ImportError as e:
-    print(f"✗ Types import failed: {e}")
+try:
+    from mcp.types import TextContent, Tool
+except ImportError:
     exit(1)
 
-print("Creating minimal server...")
 
 app = Server("edgartools")
 
@@ -42,5 +36,4 @@ async def call_tool(name: str, arguments: dict | None) -> list[TextContent]:
     return [TextContent(type="text", text=f"Hello from {name}")]
 
 if __name__ == "__main__":
-    print(f"Minimal MCP server ready: {app.name}")
-    print("This server would normally start stdio transport here")
\ No newline at end of file
+    pass
