@@ -30,21 +30,25 @@ class TableMatrix:
         self.matrix: List[List[MatrixCell]] = []
         self.row_count = 0
         self.col_count = 0
-        
+        self.header_row_count = 0  # Track number of header rows
+
     def build_from_rows(self, header_rows: List[List[Cell]], data_rows: List[Row]) -> 'TableMatrix':
         """
         Build matrix from header rows and data rows.
-        
+
         Args:
             header_rows: List of header rows (each row is a list of Cells)
             data_rows: List of Row objects
-            
+
         Returns:
             Self for chaining
         """
+        # Store header row count for later use
+        self.header_row_count = len(header_rows)
+
         # Combine all rows for processing
         all_rows = []
-        
+
         # Add header rows
         for header_row in header_rows:
             all_rows.append(header_row)
@@ -373,7 +377,35 @@ class TableMatrix:
         # If no primary headers found, use all headers as primary
         if not primary_header_cols:
             primary_header_cols = all_header_cols
-        
+
+        # Phase 1.5: Identify columns with header content
+        # Any column with non-empty text in ANY header row must be preserved
+        # This prevents legitimate header columns from being removed as "spacing"
+        # Also preserve columns that are spanned by headers (colspan > 1)
+        header_content_columns = set()
+        for col_idx in range(self.col_count):
+            for row_idx in range(self.header_row_count):
+                cell = self.matrix[row_idx][col_idx]
+                if cell.original_cell:
+                    # Check for original header cell with content
+                    if not cell.is_spanned:
+                        text = cell.original_cell.text().strip()
+                        if text:
+                            header_content_columns.add(col_idx)
+                            # Also add all columns spanned by this header
+                            if cell.original_cell.colspan > 1:
+                                for span_offset in range(1, cell.original_cell.colspan):
+                                    span_col = col_idx + span_offset
+                                    if span_col < self.col_count:
+                                        header_content_columns.add(span_col)
+                            break  # Found content, no need to check other header rows
+                    # Also preserve columns that are spanned (part of a colspan)
+                    elif cell.is_spanned:
+                        # This column is part of a header's colspan
+                        text = cell.original_cell.text().strip()
+                        if text:
+                            header_content_columns.add(col_idx)
+
         # Find columns with data (skip header rows)
         # Count actual header rows by checking for non-data content
         actual_header_rows = 0
@@ -406,6 +438,9 @@ class TableMatrix:
         # Build initial list of columns to keep
         # Always include column 0 if it contains row labels
         cols_to_keep = set(primary_header_cols)
+
+        # Add columns with header content (prevents removing legitimate headers)
+        cols_to_keep.update(header_content_columns)
         
         # Identify misaligned data columns that need to be consolidated
         # These are data columns that are not primary header columns
@@ -465,7 +500,12 @@ class TableMatrix:
             # Don't consolidate this column if it's needed as a target for parentheses
             if data_col in columns_needed_as_targets and cons_type != 'parentheses':
                 continue
-            
+
+            # CRITICAL: Don't consolidate columns that have header content
+            # This prevents legitimate header columns from being merged together
+            if data_col in header_content_columns or target_col in header_content_columns:
+                continue
+
             consolidation_map[data_col] = target_col
             # Debug: uncomment to see consolidation mapping
             # import os
@@ -587,6 +627,7 @@ class TableMatrix:
         new_matrix = TableMatrix()
         new_matrix.row_count = self.row_count
         new_matrix.col_count = len(cols_to_keep)
+        new_matrix.header_row_count = self.header_row_count  # Preserve header row count
         new_matrix.matrix = []
         
         # Create mapping from old to new column indices
