@@ -6,7 +6,14 @@ including companies, funds, and individuals.
 """
 from abc import ABC, abstractmethod
 from functools import cached_property
-from typing import List, Optional, Union, Tuple, TypeVar, Iterable
+from typing import TYPE_CHECKING, Iterable, List, Optional, Tuple, TypeVar, Union
+
+if TYPE_CHECKING:
+    import pyarrow
+
+    from edgar.entity.enhanced_statement import StructuredStatement
+    from edgar.entity.filings import EntityFilings
+    from edgar.enums import FormType, PeriodType
 
 from rich import box
 from rich.columns import Columns
@@ -18,129 +25,24 @@ from rich.text import Text
 
 from edgar._filings import Filings
 from edgar.company_reports import TenK, TenQ
-from edgar.entity.data import Address, EntityData, CompanyData
-from edgar.entity.entity_facts import EntityFacts, get_company_facts, NoCompanyFactsFound
+from edgar.entity.data import Address, CompanyData, EntityData
+from edgar.entity.entity_facts import EntityFacts, NoCompanyFactsFound, get_company_facts
 from edgar.entity.tickers import get_icon_from_ticker
 from edgar.financials import Financials
-from edgar.formatting import reverse_name, datefmt
+from edgar.formatting import datefmt, reverse_name
 from edgar.reference.tickers import find_cik
 from edgar.richtools import repr_rich
 
-# Performance optimization: use set for O(1) lookups
-COMPANY_FORMS = {
-    # Registration statements
-    "S-1", "S-3", "S-4", "S-8", "S-11",
-    # Foreign issuers registration forms
-    "F-1", "F-3", "F-4", "F-6", "F-7", "F-8", "F-9", "F-10", "F-80",
-    # Foreign form amendments and effectiveness
-    "F-6EF", "F-6 POS", "F-3ASR", "F-4MEF", "F-10EF", "F-3D", "F-3MEF",
-    # Exchange Act registration
-    "10-12B", "10-12G",
-    # Periodic reports
-    "10-K", "10-Q", "10-K/A", "10-Q/A",
-    "20-F", "40-F",  # Foreign issuers
-    "11-K",  # Employee benefit plans
-    # Current reports
-    "8-K", "6-K",
-    # Proxy materials
-    "DEF 14A", "PRE 14A", "DEFA14A", "DEFM14A",
-    # Other corporate filings
-    "424B1", "424B2", "424B3", "424B4", "424B5",
-    "ARS", "NT 10-K", "NT 10-Q",
-    "SC 13D", "SC 13G", "SC TO-I", "SC TO-T",
-    "SD", "PX14A6G",
-    # Specialized corporate filings
-    "N-CSR", "N-Q", "N-MFP", "N-CEN",
-    "X-17A-5", "17-H",
-    "TA-1", "TA-2",
-    "ATS-N",
-    # Corporate disclosures
-    "EFFECT", "FWP", "425", "CB",
-    "POS AM", "CORRESP", "UPLOAD"
-}
+if TYPE_CHECKING:
+    from edgar.enums import FormType
 
-def has_company_filings(filings_form_array: 'pyarrow.ChunkedArray', max_filings: int = 50) -> bool:
-    """
-    Efficiently check if any form in the PyArrow ChunkedArray matches company-only forms.
-    Limited to checking the first max_filings entries for performance.
-    
-    Args:
-        filings_form_array: PyArrow ChunkedArray containing form values
-        max_filings: Maximum number of filings to check
-        
-    Returns:
-        True if any form matches a company form, False otherwise
-    """
-
-    # Early exit for empty arrays
-    if filings_form_array.null_count == filings_form_array.length:
-        return False
-
-    # Handle case with fewer than max_filings
-    total_filings = filings_form_array.length()
-    filings_to_check = min(total_filings, max_filings)
-
-    # Track how many we've checked so far
-    checked_count = 0
-
-    # Process chunks in the ChunkedArray until we hit our limit
-    for chunk in filings_form_array.chunks:
-        chunk_size = len(chunk)
-
-        # If this chunk would exceed our limit, slice it
-        if checked_count + chunk_size > filings_to_check:
-            # Only check remaining forms needed to reach filings_to_check
-            remaining = filings_to_check - checked_count
-            sliced_chunk = chunk.slice(0, remaining)
-
-            # Use safer iteration over array values
-            for i in range(len(sliced_chunk)):
-                # Get value safely, handling nulls
-                val = sliced_chunk.take([i]).to_pylist()[0]
-                if val is not None and val in COMPANY_FORMS:
-                    return True
-        else:
-            # Process full chunk safely
-            for val in chunk.to_pylist():
-                if val is not None and val in COMPANY_FORMS:
-                    return True
-
-        # Update count of checked filings
-        if checked_count + chunk_size > filings_to_check:
-            checked_count += (filings_to_check - checked_count)
-        else:
-            checked_count += chunk_size
-
-        # Stop if we've checked enough
-        if checked_count >= filings_to_check:
-            break
-
-    return False
+# Import constants and utilities from separate modules
+from edgar.entity.constants import COMPANY_FORMS
+from edgar.entity.utils import has_company_filings, normalize_cik
 
 # Type variables for better type annotations
 T = TypeVar('T')
 
-def normalize_cik(cik_or_identifier: Union[str, int]) -> int:
-    """
-    Normalize a CIK to an integer by removing leading zeros.
-    
-    Args:
-        cik_or_identifier: CIK as string or int
-    
-    Returns:
-        Normalized CIK as an integer
-    """
-    if isinstance(cik_or_identifier, int):
-        return cik_or_identifier
-    
-    # If it's a string that represents an int (like '0000320193')
-    if isinstance(cik_or_identifier, str) and cik_or_identifier.isdigit():
-        return int(cik_or_identifier)
-    
-    # If it's another type of string (like a ticker), we can't normalize it
-    # This should be handled by the caller
-    return cik_or_identifier
-
 __all__ = [
     'SecFiler',
     'Entity',
@@ -157,27 +59,27 @@ __all__ = [
 class SecFiler(ABC):
     """
     Abstract base class for all SEC filing entities.
-    
+
     This is the root of the entity hierarchy and defines the common interface
     that all entity types must implement.
     """
-    
+
     @abstractmethod
     def get_filings(self, **kwargs) -> Filings:
         """Get filings for this entity."""
         pass
-        
+
     @abstractmethod
     def get_facts(self) -> Optional[EntityFacts]:
         """Get structured facts about this entity."""
         pass
-    
+
     @property
     @abstractmethod
     def cik(self) -> int:
         """Get the CIK number for this entity."""
         pass
-    
+
     @property
     @abstractmethod
     def data(self) -> 'EntityData':
@@ -188,11 +90,11 @@ class SecFiler(ABC):
 class Entity(SecFiler):
     """
     Represents any entity that files with the SEC.
-    
+
     This is the base concrete implementation that can be used directly
     or specialized for specific entity types.
     """
-    
+
     def __init__(self, cik_or_identifier: Union[str, int]):
         # If it's a ticker, convert to CIK first
         if isinstance(cik_or_identifier, str) and not cik_or_identifier.isdigit():
@@ -205,7 +107,7 @@ class Entity(SecFiler):
             self._cik = normalize_cik(cik_or_identifier)
 
         self._data = None
-    
+
     @property
     def cik(self) -> int:
         """Get the CIK number for this entity."""
@@ -224,17 +126,17 @@ class Entity(SecFiler):
         if self.is_company:
             return self.name
         return reverse_name(self.name)
-    
+
     @cached_property
     def data(self) -> 'EntityData':
         """Get detailed data for this entity."""
         if self._data is None:
             # Import locally to avoid circular imports
             from edgar.entity.submissions import get_entity_submissions
-            
+
             # get_entity_submissions returns the EntityData directly
             entity_data = get_entity_submissions(self.cik)
-            
+
             if entity_data:
                 self._data = entity_data
                 self._data._not_found = False
@@ -256,12 +158,12 @@ class Entity(SecFiler):
         if hasattr(self.data, 'business_address') and self.data.business_address:
             return self.data.business_address
 
-    
+
     @property
     def not_found(self) -> bool:
         """
         Check if the entity data was not found.
-        
+
         Returns:
             True if the entity data could not be found, False otherwise
         """
@@ -269,7 +171,7 @@ class Entity(SecFiler):
             # We haven't loaded the data yet, so we don't know if it's not found
             # Loading the data will set the not_found flag
             _ = self.data
-            
+
         return getattr(self._data, '_not_found', False)
 
     @property
@@ -292,12 +194,12 @@ class Entity(SecFiler):
         """
         return not self.is_company
 
-    
+
     def get_filings(self, 
                    *,
                    year: Union[int, List[int]] = None,
                    quarter: Union[int, List[int]] = None,
-                   form: Union[str, List] = None,
+                   form: Union[str, 'FormType', List[Union[str, 'FormType']]] = None,
                    accession_number: Union[str, List] = None,
                    file_number: Union[str, List] = None,
                    filing_date: Union[str, Tuple[str, str]] = None,
@@ -309,16 +211,16 @@ class Entity(SecFiler):
                    trigger_full_load: bool = True) -> 'EntityFilings':
         """
         Get the entity's filings and optionally filter by multiple criteria.
-        
+
         This method has a special behavior for loading filings. When first called,
         it only loads the most recent filings. If trigger_full_load=True, it will 
         automatically fetch all historical filings from the SEC (potentially making 
         multiple API calls) as needed.
-        
+
         Args:
             year: The year or list of years to filter by (e.g. 2023, [2022, 2023])
             quarter: The quarter or list of quarters to filter by (1-4, e.g. 4, [3, 4])
-            form: The form as a string e.g. '10-K' or List of strings ['10-Q', '10-K']
+            form: The form type (e.g. FormType.ANNUAL_REPORT, '10-K', or ['10-Q', '10-K'])
             accession_number: The accession number that identifies a filing
             file_number: The file number e.g. 001-39504
             filing_date: Filter by filing date (YYYY-MM-DD or range)
@@ -328,7 +230,7 @@ class Entity(SecFiler):
             is_inline_xbrl: Whether the filing is Inline XBRL
             sort_by: Sort criteria
             trigger_full_load: Whether to load all historical filings if not already loaded
-            
+
         Returns:
             Filtered filings matching the criteria
         """
@@ -347,14 +249,27 @@ class Entity(SecFiler):
             sort_by=sort_by,
             trigger_full_load=trigger_full_load
         )
-        
-    def get_facts(self) -> Optional[EntityFacts]:
-        """Get structured facts about this entity."""
+
+    def get_facts(self, period_type: Optional[Union[str, 'PeriodType']] = None) -> Optional[EntityFacts]:
+        """
+        Get structured facts about this entity.
+
+        Args:
+            period_type: Optional filter by period type. Can be PeriodType enum
+                        or string ('annual', 'quarterly', 'monthly').
+
+        Returns:
+            EntityFacts object, optionally filtered by period type
+        """
         try:
-            return get_company_facts(self.cik)
+            facts = get_company_facts(self.cik)
+            if facts and period_type:
+                # Apply period type filtering to the facts
+                return facts.filter_by_period_type(period_type)
+            return facts
         except NoCompanyFactsFound:
             return None
-    
+
     def get_structured_statement(self, 
                                 statement_type: str,
                                 fiscal_year: Optional[int] = None,
@@ -363,37 +278,37 @@ class Entity(SecFiler):
                                 include_missing: bool = False) -> Optional['StructuredStatement']:
         """
         Get a hierarchically structured financial statement.
-        
+
         This method uses learned canonical structures to build complete financial
         statements with proper hierarchy and relationships, filling in missing
         concepts when requested.
-        
+
         Args:
             statement_type: Type of statement ('BalanceSheet', 'IncomeStatement', 'CashFlow')
             fiscal_year: Fiscal year to retrieve (defaults to latest)
             fiscal_period: Fiscal period ('FY', 'Q1', 'Q2', 'Q3', 'Q4')
             use_canonical: Use canonical structure for organization (recommended)
             include_missing: Include placeholders for missing canonical concepts
-            
+
         Returns:
             StructuredStatement with hierarchical organization or None if no data
-            
+
         Example:
             >>> company = Company('AAPL')
             >>> stmt = company.get_structured_statement('IncomeStatement', 2024, 'Q4')
             >>> print(stmt.get_hierarchical_display())
         """
         from edgar.entity.statement_builder import StatementBuilder
-        
+
         facts_data = self.get_facts()
         if not facts_data:
             return None
-        
+
         # Get all facts
         all_facts = facts_data.get_all_facts()
         if not all_facts:
             return None
-        
+
         # Build the statement
         builder = StatementBuilder(cik=str(self.cik))
         structured_stmt = builder.build_statement(
@@ -404,16 +319,16 @@ class Entity(SecFiler):
             use_canonical=use_canonical,
             include_missing=include_missing
         )
-        
+
         # Add company metadata
         structured_stmt.company_name = self.name
-        
+
         return structured_stmt
-    
+
     def latest(self, form: str, n=1):
         """Get the latest filing(s) for a given form."""
         return self.get_filings(form=form, trigger_full_load=False).latest(n)
-    
+
     def __str__(self):
         if hasattr(self, 'data'):
             return f"Entity({self.data.name} [{self.cik}])"
@@ -421,14 +336,14 @@ class Entity(SecFiler):
 
     def __rich__(self):
         return self.data.__rich__()
-    
+
     def __repr__(self):
         return repr_rich(self.__rich__())
-        
+
     def __bool__(self):
         """
         Allow truthiness check for entities.
-        
+
         Returns False if the entity doesn't exist (has a sentinel CIK value or not_found is True).
         This enables code patterns like: `if company: do_something()`
         """
@@ -439,16 +354,16 @@ class Entity(SecFiler):
 class Company(Entity):
     """
     Represents a public company that files with the SEC.
-    
+
     Provides company-specific functionality like financial statements,
     ticker lookup, etc.
     """
-    
+
     def __init__(self, cik_or_ticker: Union[str, int]):
 
 
         super().__init__(cik_or_ticker)
-    
+
     @property
     def data(self) -> 'EntityData':  # We'll return the base type to simplify
         """Get detailed data for this company."""
@@ -474,14 +389,14 @@ class Company(Entity):
         if hasattr(self.data, 'exchanges'):
             return self.data.exchanges
         return []
-    
+
     def get_financials(self) -> Optional[Financials]:
         """Get financial statements for this company."""
         tenk_filing = self.latest_tenk
         if tenk_filing is not None:
             return tenk_filing.financials
         return None
-    
+
     def get_quarterly_financials(self) -> Optional[Financials]:
         """Get quarterly financial statements for this company."""
         tenq_filing = self.latest_tenq
@@ -509,7 +424,7 @@ class Company(Entity):
         if hasattr(self.data, 'sic_description'):
             return self.data.sic_description
         return None
-    
+
     @property
     def latest_tenk(self) -> Optional[TenK]:
         """Get the latest 10-K filing for this company."""
@@ -528,13 +443,13 @@ class Company(Entity):
 
     def get_icon(self):
         return get_icon_from_ticker(self.tickers[0])
-    
+
     # Enhanced financial data properties and methods
     @property
     def facts(self) -> Optional[EntityFacts]:
         """Get enhanced structured facts about this company."""
         return self.get_facts()
-    
+
     @property
     def public_float(self) -> Optional[float]:
         """Get the public float value for this company."""
@@ -542,7 +457,7 @@ class Company(Entity):
         if facts:
             return facts.public_float
         return None
-    
+
     @property
     def shares_outstanding(self) -> Optional[float]:
         """Get the shares outstanding for this company.""" 
@@ -550,17 +465,17 @@ class Company(Entity):
         if facts:
             return facts.shares_outstanding
         return None
-    
+
     def income_statement(self, periods: int = 4, annual: bool = True, as_dataframe: bool = False, concise_format: bool = False):
         """
         Get income statement data for this company.
-        
+
         Args:
             periods: Number of periods to retrieve
             annual: If True, prefer annual periods; if False, get quarterly
             as_dataframe: If True, return DataFrame; if False, return MultiPeriodStatement
             concise_format: If True, display values as $1.0B, if False display as $1,000,000,000
-            
+
         Returns:
             MultiPeriodStatement or DataFrame with income statement data, or None if not available
         """
@@ -572,17 +487,17 @@ class Company(Entity):
                 from edgar.core import log
                 log.debug(f"Error getting income statement for {self.name}: {e}")
         return None
-    
+
     def balance_sheet(self, periods: int = 4, annual: bool = True, as_dataframe: bool = False, concise_format: bool = False):
         """
         Get balance sheet data for this company.
-        
+
         Args:
             periods: Number of periods to retrieve
             annual: If True, prefer annual periods; if False, get quarterly
             as_dataframe: If True, return DataFrame; if False, return MultiPeriodStatement
             concise_format: If True, display values as $1.0B, if False display as $1,000,000,000
-            
+
         Returns:
             MultiPeriodStatement or DataFrame with balance sheet data, or None if not available
         """
@@ -594,17 +509,17 @@ class Company(Entity):
                 from edgar.core import log
                 log.debug(f"Error getting balance sheet for {self.name}: {e}")
         return None
-    
+
     def cash_flow(self, periods: int = 4, annual: bool = True, as_dataframe: bool = False, concise_format: bool = False):
         """
         Get cash flow statement data for this company.
-        
+
         Args:
             periods: Number of periods to retrieve
             annual: If True, prefer annual periods; if False, get quarterly
             as_dataframe: If True, return DataFrame; if False, return MultiPeriodStatement
             concise_format: If True, display values as $1.0B, if False display as $1,000,000,000
-            
+
         Returns:
             MultiPeriodStatement or DataFrame with cash flow data, or None if not available
         """
@@ -616,18 +531,18 @@ class Company(Entity):
                 from edgar.core import log
                 log.debug(f"Error getting cash flow for {self.name}: {e}")
         return None
-    
+
     def __str__(self):
         ticker = self.get_ticker()
         ticker_str = f" - {ticker}" if ticker else ""
         if hasattr(self, 'data'):
             return f"Company({self.data.name} [{self.cik}]{ticker_str})"
         return f"Company(CIK={self.cik}{ticker_str})"
-        
+
     def __repr__(self):
         # Delegate to the rich representation for consistency with the old implementation
         return repr_rich(self.__rich__())
-        
+
     def __rich__(self):
         """Creates a rich representation of the company with detailed information."""
 
@@ -687,7 +602,7 @@ class Company(Entity):
             trading_info.add_column("Exchange")
             trading_info.add_column("Symbol", style="bold yellow")
 
-            for exchange, ticker in zip(self.data.exchanges, self.data.tickers):
+            for exchange, ticker in zip(self.data.exchanges, self.data.tickers, strict=False):
                 trading_info.add_row(exchange, ticker)
 
             trading_panel = Panel(
@@ -712,7 +627,7 @@ class Company(Entity):
             hasattr(self.data, 'website') and self.data.website, 
             hasattr(self.data, 'investor_website') and self.data.investor_website
         ])
-        
+
         if hasattr(self.data, 'website') and self.data.website:
             contact_info.add_row("Website", self.data.website)
         if hasattr(self.data, 'investor_website') and self.data.investor_website:
@@ -745,7 +660,7 @@ class Company(Entity):
         former_names_panel = None
         if hasattr(self.data, 'former_names') and self.data.former_names:
 
-            
+
             former_names_table = Table(box=box.SIMPLE, show_header=False, padding=(0, 1))
             former_names_table.add_column("Previous Company Names")
             former_names_table.add_column("")  # Empty column for better spacing
@@ -784,7 +699,7 @@ class Company(Entity):
             subtitle="SEC Entity Data",
             border_style="grey50"
         )
-    
+
     @staticmethod
     def _get_operating_type_emoticon(entity_type: str) -> str:
         """
@@ -823,13 +738,13 @@ class Company(Entity):
 
         # Return default question mark if type not found
         return symbols.get(cleaned_type, "")
-    
+
     @staticmethod
     def _format_fiscal_year_date(date_str):
         """Format fiscal year end date in a human-readable format."""
         if not date_str:
             return "-"
-            
+
         # Dictionary of months
         months = {
             "01": "Jan", "02": "Feb", "03": "Mar",
@@ -842,7 +757,7 @@ class Company(Entity):
         month = date_str[:2]
         if month not in months:
             return date_str
-            
+
         try:
             day = str(int(date_str[2:]))  # Remove leading zero
             return f"{months[month]} {day}"
@@ -855,10 +770,10 @@ class Company(Entity):
 def get_entity(cik_or_identifier: Union[str, int]) -> Entity:
     """
     Get any SEC filing entity by CIK or identifier.
-    
+
     Args:
         cik_or_identifier: CIK number (as int or str) or other identifier
-        
+
     Returns:
         Entity instance
     """
@@ -868,10 +783,10 @@ def get_entity(cik_or_identifier: Union[str, int]) -> Entity:
 def get_company(cik_or_ticker: Union[str, int]) -> Company:
     """
     Get a public company by CIK or ticker.
-    
+
     Args:
         cik_or_ticker: CIK number or ticker symbol
-        
+
     Returns:
         Company instance
     """
@@ -881,12 +796,12 @@ def get_company(cik_or_ticker: Union[str, int]) -> Company:
 def public_companies() -> Iterable[Company]:
     """
     Iterator over all known public companies.
-    
+
     Returns:
         Iterable of Company objects
     """
     from edgar.reference.tickers import get_cik_tickers
-    
+
     df = get_cik_tickers()
     for _, row in df.iterrows():
         c = Company(row.cik)
