@@ -12,16 +12,15 @@ from typing import Any, Dict, List, Optional, Set, Tuple, Union
 
 from edgar.xbrl.core import format_date, parse_date
 from edgar.xbrl.standardization import ConceptMapper, initialize_default_mappings, standardize_statement
-from edgar.xbrl.stitching.periods import determine_optimal_periods
 from edgar.xbrl.stitching.ordering import StatementOrderingManager
+from edgar.xbrl.stitching.periods import determine_optimal_periods
 from edgar.xbrl.stitching.presentation import VirtualPresentationTree
 
 
-
 class StatementStitcher:
     """
     Combines multiple statements across time periods into a unified view.
-    
+
     This class handles the complexities of combining financial statements 
     from different periods, including:
     - Normalizing concepts that change over time
@@ -29,7 +28,7 @@ class StatementStitcher:
     - Handling missing data points
     - Providing both standardized and company-specific views
     """
-    
+
     class PeriodType(str, Enum):
         """Types of period views available for stitched statements"""
         RECENT_PERIODS = "Most Recent Periods"
@@ -39,11 +38,11 @@ class StatementStitcher:
         ANNUAL_COMPARISON = "Annual Comparison"
         QUARTERLY_TREND = "Quarterly Trend"
         ALL_PERIODS = "All Available Periods"
-    
+
     def __init__(self, concept_mapper: Optional[ConceptMapper] = None):
         """
         Initialize a StatementStitcher instance.
-        
+
         Args:
             concept_mapper: Optional ConceptMapper for standardizing concepts.
                             If None, a default mapper is created.
@@ -54,7 +53,7 @@ class StatementStitcher:
         else:
             self.concept_mapper = concept_mapper
             self.mapping_store = concept_mapper.mapping_store
-        
+
         # Initialize data structures
         self.periods = []  # Ordered list of period identifiers
         self.period_dates = {}  # Maps period ID to display dates
@@ -62,7 +61,7 @@ class StatementStitcher:
         self.concept_metadata = {}  # Metadata for each concept (level, etc.)
         self.ordering_manager = None  # Will be initialized during stitching
         self.original_statement_order = []  # Track original order for hierarchy context
-        
+
     def stitch_statements(
         self, 
         statements: List[Dict[str, Any]], 
@@ -72,13 +71,13 @@ class StatementStitcher:
     ) -> Dict[str, Any]:
         """
         Stitch multiple statements into a unified view.
-        
+
         Args:
             statements: List of statement data from different filings
             period_type: Type of period view to generate
             max_periods: Maximum number of periods to include
             standard: Whether to use standardized concept labels
-            
+
         Returns:
             Dictionary with stitched statement data
         """
@@ -88,11 +87,11 @@ class StatementStitcher:
         self.data = defaultdict(dict)
         self.concept_metadata = {}
         self.original_statement_order = []
-        
+
         # Initialize ordering manager for this statement type
         statement_type = statements[0].get('statement_type', 'IncomeStatement') if statements else 'IncomeStatement'
         self.ordering_manager = StatementOrderingManager(statement_type)
-        
+
         # Capture original statement order from the most recent (first) statement for hierarchy context
         if statements:
             reference_statement = statements[0]
@@ -104,52 +103,52 @@ class StatementStitcher:
                     self.original_statement_order.append(concept)
                 if label and label not in self.original_statement_order:
                     self.original_statement_order.append(label)
-        
+
         # Extract and sort all periods
         all_periods = self._extract_periods(statements)
 
         # Set max_periods if not provided
         max_periods = max_periods or len(statements) + 2 # Allow for the last statement to have 3 periods
-        
+
         # Select appropriate periods based on period_type
         selected_periods = self._select_periods(all_periods, period_type, max_periods)
         self.periods = selected_periods
-        
+
         # Process each statement
-        for i, statement in enumerate(statements):
+        for _i, statement in enumerate(statements):
             # Only process statements that have periods in our selection
             statement_periods = set(statement['periods'].keys())
             relevant_periods = statement_periods.intersection(set(selected_periods))
-            
+
             if not relevant_periods:
                 continue
-                
+
             # Standardize the statement if needed
             if standard:
                 processed_data = self._standardize_statement_data(statement)
             else:
                 processed_data = statement['data']
-            
+
             # Store data for each item
             self._integrate_statement_data(processed_data, statement['periods'], relevant_periods)
-        
+
         # Format the stitched data
         return self._format_output_with_ordering(statements)
-    
+
     def _extract_periods(self, statements: List[Dict[str, Any]]) -> List[Tuple[str, datetime]]:
         """
         Extract and sort all periods from the statements, de-duplicating periods with the same date.
-        
+
         Args:
             statements: List of statement data
-            
+
         Returns:
             List of (period_id, end_date) tuples, sorted by date (newest first)
         """
         # Use a dictionary to track unique periods by their end date
         # This will handle cases where different period_ids reference the same date
         unique_periods = {}  # key: date string, value: (period_id, datetime, statement_index)
-        
+
         for i, statement in enumerate(statements):
             # Use statement index (i) to prioritize more recent filings
             # Lower index = more recent filing
@@ -158,7 +157,7 @@ class StatementStitcher:
                 try:
                     # Initialize normalized_key to silence the type checker
                     normalized_key = ""
-                    
+
                     if period_id.startswith('instant_'):
                         date_str = period_id.split('_')[1]
                         # Format the date consistently with single statements
@@ -180,7 +179,7 @@ class StatementStitcher:
                             start_date = parse_date(start_date_str)
                             end_date = parse_date(end_date_str)
                             date_str = end_date_str  # Use end date for sorting
-                            
+
                             # Format end date consistently - for stitched statements,
                             # we only need the end date for duration periods as that's what users compare
                             display_date = format_date(end_date)
@@ -190,10 +189,10 @@ class StatementStitcher:
                         else:
                             # Skip malformed period IDs
                             continue
-                    
+
                     # Parse the end date for sorting
                     end_date = parse_date(date_str)
-                    
+
                     # Check if we already have this period (by normalized key)
                     if normalized_key in unique_periods:
                         existing_idx = unique_periods[normalized_key][2]
@@ -205,17 +204,17 @@ class StatementStitcher:
                         # Add new period
                         unique_periods[normalized_key] = (period_id, end_date, i)
                         self.period_dates[period_id] = display_date
-                
+
                 except (ValueError, TypeError, IndexError):
                     # Skip periods with invalid dates
                     continue
-        
+
         # Extract and sort the unique periods
         all_periods = [(period_id, end_date) for period_id, end_date, _ in unique_periods.values()]
-        
+
         # Sort by date, newest first
         return sorted(all_periods, key=lambda x: x[1], reverse=True)
-    
+
     def _select_periods(
         self, 
         all_periods: List[Tuple[str, Union[str,datetime]]],
@@ -224,12 +223,12 @@ class StatementStitcher:
     ) -> List[str]:
         """
         Select appropriate periods based on period_type.
-        
+
         Args:
             all_periods: List of (period_id, end_date) tuples
             period_type: Type of period view to generate
             max_periods: Maximum number of periods to include
-            
+
         Returns:
             List of selected period IDs
         """
@@ -239,46 +238,46 @@ class StatementStitcher:
             except ValueError:
                 # Default to recent periods if string doesn't match enum
                 period_type = StatementStitcher.PeriodType.RECENT_PERIODS
-        
+
         # Extract period types (instant vs duration)
         instants = [(pid, date) for pid, date in all_periods if pid.startswith('instant_')]
         durations = [(pid, date) for pid, date in all_periods if not pid.startswith('instant_')]
-        
+
         # Apply different selection logic based on period_type
         if period_type == StatementStitcher.PeriodType.RECENT_PERIODS:
             # Just take the most recent periods up to max_periods
             return [pid for pid, _ in all_periods[:max_periods]]
-            
+
         elif period_type == StatementStitcher.PeriodType.THREE_YEAR_COMPARISON:
             # For balance sheets, find year-end instants
             year_ends = []
             years_seen = set()
-            
+
             for pid, date in instants:
                 year = parse_date(date).year
                 if year not in years_seen and len(year_ends) < max_periods:
                     year_ends.append(pid)
                     years_seen.add(year)
-            
+
             return year_ends
-            
+
         elif period_type == StatementStitcher.PeriodType.THREE_QUARTERS:
             # Find the most recent quarters (for income statements)
             quarterly_periods = []
-            
-            for pid, date in durations:
+
+            for pid, _date in durations:
                 # Check if this appears to be a quarterly period
                 if not pid.startswith('duration_'):
                     continue
-                    
+
                 start_date_str = pid.split('_')[1]
                 end_date_str = pid.split('_')[2]
-                
+
                 try:
                     start_date = parse_date(start_date_str)
                     end_date = parse_date(end_date_str)
                     days = (end_date - start_date).days
-                    
+
                     # Assuming quarterly is around 90 days
                     if 80 <= days <= 95:
                         quarterly_periods.append(pid)
@@ -286,26 +285,26 @@ class StatementStitcher:
                             break
                 except (ValueError, TypeError, IndexError):
                     continue
-            
+
             return quarterly_periods
-            
+
         elif period_type == StatementStitcher.PeriodType.ANNUAL_COMPARISON:
             # Find annual periods (for income statements)
             annual_periods = []
-            
-            for pid, date in durations:
+
+            for pid, _date in durations:
                 # Check if this appears to be an annual period
                 if not pid.startswith('duration_'):
                     continue
-                    
+
                 start_date_str = pid.split('_')[1]
                 end_date_str = pid.split('_')[2]
-                
+
                 try:
                     start_date = parse_date(start_date_str)
                     end_date = parse_date(end_date_str)
                     days = (end_date - start_date).days
-                    
+
                     # Assuming annual is around 365 days
                     if 350 <= days <= 380:
                         annual_periods.append(pid)
@@ -313,36 +312,36 @@ class StatementStitcher:
                             break
                 except (ValueError, TypeError, IndexError):
                     continue
-            
+
             return annual_periods
-            
+
         elif period_type == StatementStitcher.PeriodType.ALL_PERIODS:
             # Return all periods, newest first, up to max_periods
             return [pid for pid, _ in all_periods[:max_periods]]
-            
+
         # Default to recent periods
         return [pid for pid, _ in all_periods[:max_periods]]
-    
+
     def _standardize_statement_data(self, statement: Dict[str, Any]) -> List[Dict[str, Any]]:
         """
         Standardize the statement data using the concept mapper.
-        
+
         Args:
             statement: Statement data
-            
+
         Returns:
             Standardized statement data
         """
         # Add statement type to context for better mapping
         statement_type = statement.get('statement_type', '')
         statement_data = statement['data']
-        
+
         for item in statement_data:
             item['statement_type'] = statement_type
-        
+
         # Apply standardization using the concept mapper
         return standardize_statement(statement_data, self.concept_mapper)
-    
+
     def _integrate_statement_data(
         self, 
         statement_data: List[Dict[str, Any]], 
@@ -351,7 +350,7 @@ class StatementStitcher:
     ) -> None:
         """
         Integrate statement data from one statement into the stitched view.
-        
+
         Args:
             statement_data: Statement data
             period_map: Map of period IDs to period information
@@ -360,26 +359,26 @@ class StatementStitcher:
         # Map to track concepts by their underlying concept ID, not just label
         # This helps merge rows that represent the same concept but have different labels
         concept_to_label_map = {}
-        
+
         for item in statement_data:
             concept = item.get('concept')
             label = item.get('label')
-            
+
             # Skip items without concept or label
             if not concept or not label:
                 continue
-                
+
             # Skip abstract items with no children (headers without data)
             if item.get('is_abstract', False) and not item.get('children'):
                 continue
-                
+
             # Skip dimension items
             if any(bracket in label for bracket in ['[Axis]', '[Domain]', '[Member]', '[Line Items]', '[Table]', '[Abstract]']):
                 continue
-            
+
             # Use concept as the primary key for identifying the same financial line item
             # This is more reliable than labels which may vary across filings
-            
+
             # If we've already seen this concept, use the existing label as the key
             # This ensures we merge rows that represent the same concept
             if concept in concept_to_label_map:
@@ -389,7 +388,7 @@ class StatementStitcher:
                 concept_key = label
                 # Remember this mapping for future occurrences
                 concept_to_label_map[concept] = concept_key
-            
+
             # Store metadata about the concept (level, abstract status, etc.)
             # If we've already seen this concept, only update metadata if it's from a more recent period
             # This ensures we use labels from the most recent filing when merging rows
@@ -405,41 +404,41 @@ class StatementStitcher:
                 # For existing concepts, update the label to use the most recent one
                 # We determine which periods are most recent based on position in self.periods
                 # (earlier indices are more recent periods)
-                
+
                 # Find the periods in this statement
                 statement_periods = [p for p in relevant_periods if p in self.periods]
                 if statement_periods:
                     # Get the most recent period in this statement
                     most_recent_period = min(statement_periods, key=lambda p: self.periods.index(p))
                     most_recent_idx = self.periods.index(most_recent_period)
-                    
+
                     # Find the earliest period where we have data for this concept
                     existing_periods = [p for p in self.data[concept_key].keys() if p in self.periods]
                     if existing_periods:
                         earliest_existing_idx = min(self.periods.index(p) for p in existing_periods)
-                        
+
                         # If this statement has more recent data, update the label
                         if most_recent_idx < earliest_existing_idx:
                             # Update the concept key label for display
                             new_concept_key = label
-                            
+
                             # If we're changing the label, we need to migrate existing data
                             if new_concept_key != concept_key:
                                 # Copy existing data to the new key
                                 if new_concept_key not in self.data:
                                     self.data[new_concept_key] = self.data[concept_key].copy()
-                                    
+
                                 # Update metadata
                                 self.concept_metadata[new_concept_key] = self.concept_metadata[concept_key].copy()
                                 self.concept_metadata[new_concept_key]['latest_label'] = label
-                                
+
                                 # Update the concept mapping
                                 concept_to_label_map[concept] = new_concept_key
                                 concept_key = new_concept_key
                             else:
                                 # Just update the latest label
                                 self.concept_metadata[concept_key]['latest_label'] = label
-            
+
             # Store values for relevant periods
             for period_id in relevant_periods:
                 if period_id in self.periods:  # Only include selected periods
@@ -449,14 +448,14 @@ class StatementStitcher:
                             'value': value,
                             'decimals': item.get('decimals', {}).get(period_id, 0)
                         }
-    
+
     def _format_output_with_ordering(self, statements: List[Dict[str, Any]]) -> Dict[str, Any]:
         """
         Format the stitched data for rendering with intelligent ordering using virtual presentation tree.
-        
+
         Args:
             statements: Original statements for ordering reference
-            
+
         Returns:
             Stitched statement data in the expected format
         """
@@ -464,7 +463,7 @@ class StatementStitcher:
         concept_ordering = {}
         if self.ordering_manager:
             concept_ordering = self.ordering_manager.determine_ordering(statements)
-        
+
         # Build virtual presentation tree to preserve hierarchy while applying semantic ordering
         presentation_tree = VirtualPresentationTree(self.ordering_manager)
         ordered_nodes = presentation_tree.build_tree(
@@ -472,16 +471,16 @@ class StatementStitcher:
             concept_ordering=concept_ordering,
             original_statement_order=self.original_statement_order
         )
-        
+
         # Convert nodes back to the expected format
         ordered_concepts = [(node.concept, node.metadata) for node in ordered_nodes]
-        
+
         # Build the output structure
         result = {
             'periods': [(pid, self.period_dates.get(pid, pid)) for pid in self.periods],
             'statement_data': []
         }
-        
+
         for concept, metadata in ordered_concepts:
             # Create an item for each concept
             item = {
@@ -494,26 +493,26 @@ class StatementStitcher:
                 'values': {},
                 'decimals': {}
             }
-            
+
             # Add values for each period
             for period_id in self.periods:
                 if period_id in self.data[concept]:
                     item['values'][period_id] = self.data[concept][period_id]['value']
                     item['decimals'][period_id] = self.data[concept][period_id]['decimals']
-            
+
             # Set has_values flag based on whether there are any values
             item['has_values'] = len(item['values']) > 0
-            
+
             # Only include items with values or abstract items
             if item['has_values'] or item['is_abstract']:
                 result['statement_data'].append(item)
-        
+
         return result
-    
+
     def _format_output(self) -> Dict[str, Any]:
         """
         Backward compatibility method - calls the new ordering-aware method.
-        
+
         Returns:
             Stitched statement data in the expected format
         """
@@ -533,7 +532,7 @@ def stitch_statements(
 ) -> Dict[str, Any]:
     """
     Stitch together statements from multiple XBRL objects.
-    
+
     Args:
         xbrl_list: List of XBRL objects, should be from the same company and ordered by date
         statement_type: Type of statement to stitch ('IncomeStatement', 'BalanceSheet', etc.)
@@ -542,36 +541,36 @@ def stitch_statements(
         standard: Whether to use standardized concept labels (default: True)
         use_optimal_periods: Whether to use the entity info to determine optimal periods (default: True)
         include_dimensions: Whether to include dimensional segment data (default: False for stitching)
-        
+
     Returns:
         Stitched statement data
     """
     # Initialize the stitcher
     stitcher = StatementStitcher()
-    
+
     # Collect statements of the specified type from each XBRL object
     statements = []
-    
+
     # If using optimal periods based on entity info
     if use_optimal_periods:
         # Use our utility function to determine the best periods
         optimal_periods = determine_optimal_periods(xbrl_list, statement_type, max_periods=max_periods)
-        
+
         # Limit to max_periods if needed
         if len(optimal_periods) > max_periods:
             optimal_periods = optimal_periods[:max_periods]
-            
+
         # Extract the XBRL objects that contain our optimal periods
         for period_metadata in optimal_periods:
             xbrl_index = period_metadata['xbrl_index']
             xbrl = xbrl_list[xbrl_index]
-            
+
             # Get the statement and period info
             statement = xbrl.get_statement_by_type(statement_type, include_dimensions=include_dimensions)
             if statement:
                 # Only include the specific period from this statement
                 period_key = period_metadata['period_key']
-                
+
                 # Check if this period exists in the statement
                 if period_key in statement['periods']:
                     # Create a filtered version of the statement with just this period
@@ -582,12 +581,12 @@ def stitch_statements(
                         'periods': {period_key: statement['periods'][period_key]},
                         'data': statement['data']
                     }
-                    
+
                     # Update the period label to include information from entity_info
                     display_date = period_metadata['display_date']
                     period_type = period_metadata['period_type']
                     fiscal_period = period_metadata.get('fiscal_period')
-                    
+
                     # Create a more informative label
                     if period_type == 'instant':
                         if fiscal_period == 'FY':
@@ -602,13 +601,13 @@ def stitch_statements(
                             period_label = f"{fiscal_period} {display_date}"
                         else:
                             period_label = display_date
-                            
+
                     # Update the period label
                     filtered_statement['periods'][period_key] = {
                         'label': period_label,
                         'original_label': statement['periods'][period_key]['label']
                     }
-                    
+
                     statements.append(filtered_statement)
     # Traditional approach without using entity info
     else:
@@ -617,6 +616,6 @@ def stitch_statements(
             statement = xbrl.find_statement(statement_type)
             if statement:
                 statements.append(statement)
-    
+
     # Stitch the statements
-    return stitcher.stitch_statements(statements, period_type, max_periods, standard)
\ No newline at end of file
+    return stitcher.stitch_statements(statements, period_type, max_periods, standard)
